@@ -609,7 +609,7 @@ void archive::clear()
 /** Delete cached unarchived expressions in all archive_nodes (mainly for debugging). */
 void archive::forget()
 {
-	for_each(nodes.begin(), nodes.end(), std::mem_fun_ref(&archive_node::forget));
+	for_each(nodes.begin(), nodes.end(), std::mem_fn(&archive_node::forget));
 }
 
 /** Delete cached unarchived expressions from node (for debugging). */
